<?php
defined('ABSPATH') or die('This page may not be accessed directly.');

class WonderPushPublic {
  const INSTALLATION_ID_COOKIE_NAME = 'WonderPushInstallationId';
  static function init() {
    add_action('wp_head', array(__CLASS__, 'wonderpush_snippet'), 10);
    if (WonderPushUtils::get_woocommerce()
        && WonderPushSettings::getSettings()->getEnableCartReminder()) {
      add_action('wp_head', array(__CLASS__, 'wonderpush_cookie'), 10);
    }
    // AMP support through plugin:
    // https://wordpress.org/plugins/amp/
    add_filter('amp_post_template_file', array(__CLASS__, 'amp_post_template_file'), 10, 3);
    add_filter('amp_post_article_header_meta', array(__CLASS__, 'amp_post_article_header_meta'), 10, 3);
    add_filter('amp_post_article_footer_meta', array(__CLASS__, 'amp_post_article_footer_meta'), 10, 3);
//    add_filter('amp_post_template_data', array(__CLASS__, 'amp_post_template_data'), 10, 3 );

    // AMP support through plugin:
    // https://wordpress.org/plugins/accelerated-mobile-pages/
    add_filter('ampforwp_after_header', array(__CLASS__, 'ampforwp_after_header'), 10, 3);
    add_filter('amp_post_template_above_footer', array(__CLASS__, 'amp_post_template_above_footer'), 10, 3);

    // AMP support, common to both plugins
    add_filter('amp_post_template_head', array(__CLASS__, 'amp_post_template_head'), 10, 3);
    add_action('amp_post_template_css', array(__CLASS__, 'amp_post_template_css'));
  }

  public static function amp_post_template_head() {
      ?><script type='text/javascript' src='https://cdn.ampproject.org/v0/amp-web-push-0.1.js' async custom-element="amp-web-push"></script><?php
  }
  public static function amp_post_template_data($data) {
      if (!isset($data['amp_component_scripts']) || !is_array($data['amp_component_scripts'])) {
          $data['amp_component_scripts'] = array();
      }
      $data['amp_component_scripts']['amp-web-push'] = 'https://cdn.ampproject.org/v0/amp-web-push-0.1.js';
      return $data;
  }
  public static function amp_post_article_header_meta($meta) {
      if (is_array($meta)) {
          if (!WonderPushSettings::getSettings()->getDisableAmpTopSubscribeButton()
            || !WonderPushSettings::getSettings()->getDisableAmpBottomSubscribeButton()) {
            $meta []= 'wonderpush-amp-web-push';
          }
          if (!WonderPushSettings::getSettings()->getDisableAmpTopSubscribeButton()) {
              $meta []= 'wonderpush-amp-web-push-widget';
          }
      }
      return $meta;
  }
  public static function amp_post_article_footer_meta($meta) {
      if (is_array($meta)
        && !WonderPushSettings::getSettings()->getDisableAmpBottomSubscribeButton()) {
          $meta []= 'wonderpush-amp-web-push-widget';
      }
      return $meta;
  }
  public static function amp_post_template_file($file, $type, $post) {
      if (basename($file) === 'wonderpush-amp-web-push.php') {
          return WONDERPUSH_PLUGIN_PATH . '/amp/amp-web-push.php';
      }
      if (basename($file) === 'wonderpush-amp-web-push-widget.php') {
        return WONDERPUSH_PLUGIN_PATH . '/amp/amp-web-push-widget.php';
      }
      return $file;
  }
  public static function amp_post_template_css() {
      include WONDERPUSH_PLUGIN_PATH . '/amp/style.php';
  }
  public static function ampforwp_after_header() {
      if (!WonderPushSettings::getSettings()->getDisableAmpTopSubscribeButton()
          || !WonderPushSettings::getSettings()->getDisableAmpBottomSubscribeButton()) {
          include WONDERPUSH_PLUGIN_PATH . '/amp/amp-web-push.php';
      }
      if (!WonderPushSettings::getSettings()->getDisableAmpTopSubscribeButton()) {
          include WONDERPUSH_PLUGIN_PATH . '/amp/amp-web-push-widget.php';
      }
  }
  public static function amp_post_template_above_footer() {
      if (WonderPushSettings::getSettings()->getDisableAmpBottomSubscribeButton()) {
          return;
      }
      include WONDERPUSH_PLUGIN_PATH . '/amp/amp-web-push-widget.php';
  }
  public static function wonderpush_snippet() {
    if (!WonderPushUtils::is_wonderpush_installed()) return;
    $settings = WonderPushSettings::getSettings();
    $access_token = $settings->getAccessToken();
    try {
      $app = WonderPushUtils::application_from_access_token($access_token);
    } catch (Exception $e) {
      return;
    }
    if (!$app) return;
    $web_key = $app->getWebKey();
    $by_wonderpush_domain = $app->getWebSdkInitOptions() ? $app->getWebSdkInitOptions()->getByWonderPushDomain() : null;
    if (!$web_key) return;
    ?>
    <script src="https://cdn.by.wonderpush.com/sdk/1.1/wonderpush-loader.min.js" async></script>
    <script>
      window.WonderPush = window.WonderPush || [];
      WonderPush.push(["init", {
        webKey: "<?php echo $web_key?>",
        <?php echo $by_wonderpush_domain ? '' : 'customDomain: "' . WONDERPUSH_PLUGIN_URL . 'assets/sdk/",' . "\n" ?>
      }]);
    </script>
    <?php
  }
  public static function wonderpush_cookie() {
    if (!WonderPushUtils::is_wonderpush_installed()) return;
    ?>
    <script>
      (function() {
        window.addEventListener('WonderPushEvent', function(event) {
          if (event.detail.name === 'session') {
            window.WonderPush.push(function() {
              window.WonderPush.getInstallationId()
                .then(function(installationId) {
                  document.cookie = '<?php echo self::INSTALLATION_ID_COOKIE_NAME ?>=' + encodeURIComponent(installationId || '') + '; expires=' + new Date(new Date().getTime() + 86400000).toGMTString() + '; path=/';
                });
            });
          }
        });
      })();
    </script>
    <?php
  }
}