<?php
class WonderPushSettings {
  /** @var WonderPushSettings */
  static $instance;
  static $defaults = array(
  );
  /** @var array */
  private $settings;

  private function __construct($settings) {
    if (is_array($settings)) $this->settings = $settings;
    else $this->settings = array();
  }

  private function get($name) {
    if (isset($this->settings[$name])) return $this->settings[$name];
    return array_key_exists($name, self::$defaults) ? self::$defaults[$name] : null;
  }

  private function set($name, $value) {
    if ($value === null) unset($this->settings[$name]);
    else $this->settings[$name] = $value;
    return $this;
  }

  public function getAccessToken() {
    return $this->get('accessToken');
  }

  public function setAccessToken($value) {
    return $this->set('accessToken', $value);
  }

  public function getDisableSnippet() {
    return $this->get('disableSnippet') ? true : false;
  }

  public function setDisableSnippet($value) {
    return $this->set('disableSnippet', $value ? true : false);
  }

  public function getDisableSendOnPublish() {
    return $this->get('disableSendOnPublish') ? true : false;
  }

  public function setDisableSendOnPublish($value) {
    return $this->set('disableSendOnPublish', $value ? true : false);
  }

  public function getDisableSendByDefaultOnPublish() {
    return $this->get('disableSendByDefaultOnPublish') ? true : false;
  }

  public function setDisableSendByDefaultOnPublish($value) {
    return $this->set('disableSendByDefaultOnPublish', $value ? true : false);
  }

  public function getDisableFeedbackOnPublish() {
    return $this->get('disableFeedbackOnPublish') ? true : false;
  }

  public function setDisableFeedbackOnPublish($value) {
    return $this->set('disableFeedbackOnPublish', $value ? true : false);
  }

  public function getDisableUsePostImageForIcon() {
    return $this->get('disableUsePostImageForIcon') ? true : false;
  }

  public function setDisableUsePostImageForIcon($value) {
    return $this->set('disableUsePostImageForIcon', $value ? true : false);
  }

  public function getDisableUsePostImageForLargeImage() {
    return $this->get('disableUsePostImageForLargeImage') ? true : false;
  }

  public function setDisableUsePostImageForLargeImage($value) {
    return $this->set('disableUsePostImageForLargeImage', $value ? true : false);
  }

  public function getNotificationTitle() {
    return $this->get('notificationTitle');
  }

  public function setNotificationTitle($value) {
    return $this->set('notificationTitle', $value);
  }

  public function getEnableCartReminder() {
    return $this->get('enableCartReminder') ? true : false;
  }

  public function setEnableCartReminder($value) {
    return $this->set('enableCartReminder', $value ? true : false);
  }

  public function getCartReminderStrategy() {
    $value = $this->get('cartReminderStrategy');
    return $value ? $value : WonderPushWooCommerce::CART_REMINDER_STRATEGY_LATEST;
  }

  public function setCartReminderStrategy($value) {
    return array_search($value, WonderPushWooCommerce::cart_reminder_strategies()) !== false
      ? $this->set('cartReminderStrategy', $value) : $this;
  }

  public function getCartReminderDestination() {
    $value = $this->get('cartReminderDestination');
    return $value ? $value : WonderPushWooCommerce::CART_REMINDER_DESTINATION_HOMEPAGE;
  }

  public function setCartReminderDestination($value) {
    return array_search($value, WonderPushWooCommerce::cart_reminder_destinations()) !== false
      ? $this->set('cartReminderDestination', $value) : $this;
  }

  public function getCartReminderMessage() {
    return $this->get('cartReminderMessage');
  }

  public function setCartReminderMessage($value) {
    $this->set('cartReminderMessage', $value);
    return $this;
  }

  public function getDisableCartReminderImage() {
    return $this->get('disableCartReminderImage') ? true : false;
  }

  public function setDisableCartReminderImage($value) {
    return $this->set('disableCartReminderImage', $value ? true : false);
  }

  public function getDisableAmpUnsubscribe() {
    return $this->get('disableAmpUnsubscribe') ? true : false;
  }

  public function setDisableAmpUnsubscribe($value) {
    return $this->set('disableAmpUnsubscribe', $value ? true : false);
  }

  public function getAmpSubscribeButtonLabel() {
    return $this->get('ampSubscribeButtonLabel');
  }

  public function setAmpSubscribeButtonLabel($value) {
    return $this->set('ampSubscribeButtonLabel', $value ? $value : null);
  }

  public function getAmpUnsubscribeButtonLabel() {
    return $this->get('ampUnsubscribeButtonLabel');
  }

  public function setAmpUnsubscribeButtonLabel($value) {
    return $this->set('ampUnsubscribeButtonLabel', $value ? $value : null);
  }

  public function getDisableAmpTopSubscribeButton() {
    return $this->get('disableAmpTopSubscribeButton') ? true : false;
  }

  public function setDisableAmpTopSubscribeButton($value) {
    return $this->set('disableAmpTopSubscribeButton', $value ? true : false);
  }

  public function getDisableAmpBottomSubscribeButton() {
    return $this->get('disableAmpBottomSubscribeButton') ? true : false;
  }

  public function setDisableAmpBottomSubscribeButton($value) {
    return $this->set('disableAmpBottomSubscribeButton', $value ? true : false);
  }

  public function getAmpButtonWidth() {
    return $this->get('ampButtonWidth');
  }

  public function setAmpButtonWidth($value) {
    return $this->set('ampButtonWidth', is_int($value) ? $value : null);
  }

  public function getAmpButtonHeight() {
    return $this->get('ampButtonHeight');
  }

  public function setAmpButtonHeight($value) {
    return $this->set('ampButtonHeight', is_int($value) ? $value : null);
  }

  public function getUtmParameter($parameter) {
    $parameter = str_replace('utm_', '', $parameter);
    $parameter = ucfirst($parameter);
    return $this->{"getUtm$parameter"}();
  }
  public function setUtmParameter($parameter, $value) {
    $parameter = str_replace('utm_', '', $parameter);
    $parameter = ucfirst($parameter);
    return $this->{"setUtm$parameter"}($value);
  }
  public function getUtmSource() {
    return $this->get('utmSource');
  }

  public function setUtmSource($value) {
    $this->set('utmSource', $value);
    return $this;
  }

  public function getUtmMedium() {
    return $this->get('utmMedium');
  }

  public function setUtmMedium($value) {
    $this->set('utmMedium', $value);
    return $this;
  }

  public function getUtmCampaign() {
    return $this->get('utmCampaign');
  }

  public function setUtmCampaign($value) {
    $this->set('utmCampaign', $value);
    return $this;
  }

  public function getUtmTerm() {
    return $this->get('utmTerm');
  }

  public function setUtmTerm($value) {
    $this->set('utmTerm', $value);
    return $this;
  }

  public function getUtmContent() {
    return $this->get('utmContent');
  }

  public function setUtmContent($value) {
    $this->set('utmContent', $value);
    return $this;
  }

  public function save() {
    update_option('WonderPushSettings', $this->settings);
  }

  /**
   * @return WonderPushSettings
   */
  public static function getSettings() {
    if (!self::$instance) self::$instance = new WonderPushSettings(get_option('WonderPushSettings'));
    return self::$instance;
  }
}